# Baygon Changelog

## 0.5.0 (2022-11-10)

- Code Refactoring
- Migrate documentation from VuePress 1.x to 2.x
- Add new features
- Add optional `points` to config file to rank tests
- Add `--json` option to `baygon` command

## 0.2.1

- Use config.cfg
- Fix documentation (exit-status -> exit)

## 0.2.0

- Add negation `not` keyword
- PATH is resolved for binaries
